/**
 * This file is part of the XP-Framework
 *
 * Aftermath plugin for Sonar
 * Copyright (c) 2011, XP-Framework Team
 */
package net.xp_forge.sonar.plugins.aftermath.php;

import java.io.File;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.sonar.api.resources.Project;
import org.sonar.api.batch.Phase;
import org.sonar.api.batch.SensorContext;
import org.sonar.api.batch.AbstractSourceImporter;

import net.xp_forge.sonar.plugins.aftermath.php.PhpLanguage;

/**
 * Simple source code importer for PHP projects
 *
 */
@Phase(name = Phase.Name.PRE)
public class PhpSourceImportSensor extends AbstractSourceImporter {
  private static final Logger LOG= LoggerFactory.getLogger(PhpSourceImportSensor.class);

  /**
   * Constructor
   *
   */
  public PhpSourceImportSensor(PhpLanguage language) {
    super(language);
  }

  /**
   * {@inheritDoc}
   *
   */
  @Override
  public void analyse(Project project, SensorContext context) {

    // Fix project source directories
    if (project.getFileSystem().getSourceDirs().isEmpty()) {
      File sourceDir= new File(
        project.getFileSystem().getBasedir(),
        "src" + File.separator + "main" + File.separator + this.getLanguage().getKey()
      );

      if (sourceDir.exists()) {
        PhpSourceImportSensor.LOG.info("- Adding [" + sourceDir + "] to sources");
        project.getFileSystem().addSourceDir(sourceDir);
      }
    }

    // Fix project test directories
    if (project.getFileSystem().getTestDirs().isEmpty()) {
      File testDir= new File(
        project.getFileSystem().getBasedir(),
        "src" + File.separator + "test" + File.separator + this.getLanguage().getKey()
      );

      if (testDir.exists()) {
        PhpSourceImportSensor.LOG.info("- Adding [" + testDir + "] to tests");
        project.getFileSystem().addTestDir(testDir);
      }
    }

    // Call super
    super.analyse(project, context);
  }

  /**
   * {@inheritDoc}
   *
   */
  @Override
  public String toString() {
    return "Aftermath Source Importer";
  }
}
